<?php

namespace App\Providers;

use Illuminate\Cache\RateLimiting\Limit;
use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\RateLimiter;
use Illuminate\Support\Facades\Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * The path to the "home" route for your application.
     *
     * This is used by Laravel authentication to redirect users after login.
     *
     * @var string
     */
    public const HOME = '/accounts';

    /**
     * The controller namespace for the application.
     *
     * When present, controller route declarations will automatically be prefixed with this namespace.
     *
     * @var string|null
     */
    protected $namespace = 'App\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     */
    public function boot() : void
    {
        Route::pattern('settingName', '[a-zA-Z]+');
        $this->configureRateLimiting();

        $this->routes(function () {
            Route::prefix('api/v1')
                ->middleware('api.v1')
                ->namespace($this->getApiNamespace('1'))
                ->group(base_path('routes/api/v1.php'));

            // Route::prefix('api/v2')
            //     ->middleware('api.v2')
            //     ->namespace($this->getApiNamespace(2))
            //     ->group(base_path('routes/api/v2.php'));

            Route::middleware('web')
                ->namespace($this->namespace)
                ->group(base_path('routes/web.php'));
        });
    }

    /**
     * Build Api namespace based on provided version
     *
     * @return string The Api namespace
     */
    private function getApiNamespace(string $version)
    {
        return 'App\Api\v' . $version . '\Controllers';
    }

    /**
     * Configure the rate limiters for the application.
     *
     * @return void
     */
    protected function configureRateLimiting()
    {
        RateLimiter::for('api', function (Request $request) {
            $maxAttempts = config('2fauth.api.throttle');

            return is_null($maxAttempts) ? Limit::none() : Limit::perMinute($maxAttempts)->by($request->ip());
        });
    }
}
